@@ -12,18 +12,14 @@ def get_sp500():
 	df = pd.read_html(str(table))
 	return df[0]
 
-get_sp500()
-
-def get_nasdaq():
+def get_nasdaq(): # Right now this returns nasdaq-100, should I make it just regular nasdaq (3,300 stocks)
 	request = get('https://en.wikipedia.org/wiki/Nasdaq-100')
 	soup = BeautifulSoup(request.text, 'lxml')
 	table = soup.find('table', {'id': 'constituents'})
 	df = pd.read_html(str(table))
 	return df[0]
 
-get_nasdaq()
-
-def get_nyse():
+def get_nyse(): # Test to see if duplicate tickers on backend or Django webapp
 	dfs = []
 	for letter in 'abcdefghijklmnopqrstuvwxyz':
 		request = get(f'https://eoddata.com/stocklist/NYSE/{letter}.htm')
@@ -33,7 +29,7 @@ def get_nyse():
 		dfs.append(df[0])
 	return pd.concat(dfs)
 
-get_nyse()
+
 
 # def get_biggest_movers():
 # 	tickers = []
